<?php
/*
Plugin Name: Shopp + Constant Contact
Description: Customers who opt-in to email marketing from your WordPress e-commerce site during checkout are automatically added to a specified list on Constant Contact.
Version: 1.0
Plugin URI: http://optimizemyshopp.com/blog/
Author: Lorenzo Orlando Caum, Enzo12 LLC
Author URI: http://enzo12.com
License: GPL3
*/
/* (CC BY 3.0) 2011  Lorenzo Orlando Caum  (email : hello@enzo12.com)

	This plugin is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This plugin is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this plugin.  If not, see <http://www.gnu.org/licenses/>. 
*/

require_once('inc/constant-contact.php');

class Shopp_ConstantContact {
	public static $username;
	public static $password;
	public static $api_key;
	public static $list_id;

	public function __construct() {
		add_action('shopp_init', array(&$this, 'init'));
		add_action('shopp_order_success', array(&$this, 'add_to_constant_contact_list'));
		
		$this->username = get_option("shopp_constant_contact_username");
		$this->password = get_option("shopp_constant_contact_password");
		$this->api_key = get_option("shopp_constant_contact_api_key");
		$this->list_id = get_option("shopp_constant_contact_list_id");
	}

	public function init() {
		wp_enqueue_style( 'shopp-constant-contact-stylesheet', plugins_url( "css/shopp-constant-contact.css", __FILE__ ), array(), '20111107' );
		
		// Actions and filters
		add_action('admin_menu', array(&$this, 'admin_menu'));
	}

	public function admin_menu() {
		global $Shopp;
		$ShoppMenu = $Shopp->Flow->Admin->MainMenu;
		add_submenu_page($ShoppMenu,__('Shopp + Constant Contact', 'page title'), __('+ Constant Contact','menu title'), defined('SHOPP_USERLEVEL') ? SHOPP_USERLEVEL : 'manage_options', 'shopp-constant-contact', array(&$this, 'render_display_settings'));

		add_action( 'admin_print_styles-' . $page, 'admin_styles' );
	}
	
 	public function admin_styles() {
       	wp_enqueue_style( 'shopp-constant-contact-stylesheet' );
  	}

	public function add_to_constant_contact_list($Purchase) {
		global $wpdb;
		
		$marketing = $wpdb->get_var("SELECT marketing FROM ".$wpdb->prefix."shopp_customer WHERE id = '".	$Purchase->customer."'");
		
		if ($marketing == "yes") {			
			$constant_contact_api = new constant_contact($this->username, $this->password, $this->api_key);
			
			$constant_contact_user = array(
				'EmailAddress' => $Purchase->email,
				'FirstName' => $Purchase->firstname,
				'LastName' => $Purchase->lastname,
				'OptInSource' => 'ACTION_BY_CUSTOMER'
			);
			
			$constant_contact_api->add_contact($constant_contact_user, array($this->list_id));
		}
	}

	public function render_display_settings() {
		wp_nonce_field('shopp-constant-contact');
		
		if(!empty($_POST['submit'])){
			$this->username = stripslashes($_POST['username']);
			$this->password = stripslashes($_POST['password']);
			$this->api_key = stripslashes($_POST['api_key']);
			$this->list_id = stripslashes($_POST['list_id']);
			
			update_option("shopp_constant_contact_username", $this->username);
			update_option("shopp_constant_contact_password", $this->password);
			update_option("shopp_constant_contact_api_key", $this->api_key);
			update_option("shopp_constant_contact_list_id", $this->list_id);
		}
?>
		<div class="wrap">
								
				<h2>Shopp + Constant Contact</h2>
				<div class="postbox-container" style="width:70%;">
					<div class="metabox-holder">	

			<div id="introduction" class="postbox">
				<h3 class="hndle"><span>Introduction</span></h3>
				<div class="inside">
<p>This plugin integrates <a href="http://optimizemyshopp.com/go/shopp/" title="Learn more about Shopp">Shopp</a> with <a href="http://optimizemyshopp.com/go/constantcontact/" title="Learn more about Constant Contact">Constant Contact</a>.</p> 
<p>During check out, a customer has the option to opt-in to email marketing. If they choose to do so, they will be added to a specified email list on Constant Contact.</p>
<p>This process only occurs if the customer places a check in the email marketing checkbox during check out.</p>
<p><strong>Example of Email Marketing Opt-in for Shopp</strong><br /><br /><img src="<?php echo plugins_url( 'shopp-constant-contact/images/shopp-email-marketing-opt-in.png' , dirname(__FILE__) ); ?>" alt="Shopp email marketing opt-in" title="Shopp email marketing opt-in" /></p>
</div>
			</div>

			<div id="general-settings" class="postbox">
				<h3 class="hndle"><span>Setup Tutorial</span></h3>
				<div class="inside">
				<p>Pro-tip: After starting a video, click on the fullscreen button which appears to the right of the HD logo.</p>
<p><strong>A Walkthrough of the Integration</strong><br /><br /><iframe src="http://player.vimeo.com/video/31882305?title=0&amp;byline=0&amp;portrait=0" width="600" height="300" frameborder="0" webkitAllowFullScreen allowFullScreen></iframe></p>
<br />
<p><strong>How to Find Your Information from Constant Contact</strong><br /><br /><iframe src="http://player.vimeo.com/video/31883279?title=0&amp;byline=0&amp;portrait=0" width="600" height="300" frameborder="0" webkitAllowFullScreen allowFullScreen></iframe></p>
</div>
			</div>
			<div id="support-feedback" class="postbox">
				<h3 class="hndle"><span>Support & Feedback</span></h3>
				<div class="inside">
				<p>This is a 3rd-party integration. Support is provided as a courtesy by Lorenzo Orlando Caum, Enzo12 LLC. If you have any questions or concerns, please open a <a href="http://optimizemyshopp.com/support/" title="Open a new support ticket with Optimize My Shopp">new support ticket</a> via our Help Desk.</p>
				<p>You can share feedback via this a <a href="http://enzo12llc.polldaddy.com/s/shopp-constant-contact" title="Take a super short survey">short survey</a>. Takes less 3 minutes -- we promise!</p>
				<p>Feeling generous? Please consider <a href="http://optimizemyshopp.com/go/donate-shopp-constant-contact/">donating</a>. You'll be helping me pay off my student loans at a quicker rate.</p>
</div>
			</div>
					<div id="constant-contact-settings" class="postbox">
				<h3 class="hndle"><span>Constant Contact Settings</span></h3>
				<div class="inside"><p>
					<form action="" method="post">
					<table>
					<tr>
						<th>Username:</th>
						<td><input type="text" name="username" size="35" value="<?php echo $this->username; ?>" /></td>
					</tr>
					<tr>
						<th>Password:</th>
						<td><input type="password" name="password" size="35" value="<?php echo $this->password; ?>" /></td>
					</tr>
					<tr>
						<th>API Key:</th>
						<td><input type="text" name="api_key" size="35" value="<?php echo $this->api_key; ?>" /></td>
					</tr>
					<tr>
						<th>List ID:</th>
						<td><input type="text" name="list_id"  size="35" value="<?php echo $this->list_id; ?>" /></td>
					</tr>
					</table>
					<input type="submit" class="button-primary" value="Save Settings" name="submit" />
					</form>		
</p>		
</div>
						</div>
					</div>
				</div>
				<div class="postbox-container" style="width:20%;">
				<div class="metabox-holder">	
					
				<div id="have-a-question" class="postbox">
				<h3 class="hndle"><span>Have a Question?</span></h3>
				<div class="inside">
					<p>View our <a title="View frequently asked questions at Optimize My Shopp" href="http://optimizemyshopp.com/support/frequently-asked-questions/">frequently asked questions</a>.<br /><br />Open a <a href="http://optimizemyshopp.com/support/" title="Open a new support ticket with Optimize My Shopp">new support ticket</a>.</p></div>
			</div>

				<div id="enjoy-this-plugin" class="postbox">
				<h3 class="hndle"><span>Enjoy this Plugin?</span></h3>
				<div class="inside">
					<p><ol><li><strong>Rate it </strong><a href="http://wordpress.org/extend/plugins/shopp-constant-contact/">5 stars on WordPress.org</li></a><li><strong>Spread social joy</strong> ;)<br />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://optimizemyshopp.com/blog/" data-text="Shopp + Constant Contact for my #WordPress #ecommerce store" data-count="none" data-via="enzo12llc" data-related="lorenzocaum:entrepreneur">Tweet</a><script type="text/javascript" src="//platform.twitter.com/widgets.js"></script><br /><br /><div id="fb-root"></div>
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) {return;}
  js = d.createElement(s); js.id = id;
  js.src = "//connect.facebook.net/en_US/all.js#xfbml=1";
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>

<div class="fb-like" data-href="https://www.facebook.com/pages/Optimize-My-Shopp/119961178103810" data-send="false" data-layout="button_count" data-width="5" data-show-faces="false" data-font="lucida grande">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</div><br /><br /> <!-- Place this tag where you want the +1 button to render -->
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<div class="g-plusone" data-annotation="inline" data-width="120" data-href="http://optimizemyshopp.com/blog/"></div>

<!-- Place this render call where appropriate -->
<script type="text/javascript">
  (function() {
    var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
    po.src = 'https://apis.google.com/js/plusone.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
  })();
</script></li><li><strong>Show your kindness</strong> with a <a href="http://optimizemyshopp.com/go/donate-shopp-constant-contact/">donation</a></li></p></div>
			</div>

				<div id="news-from-oms" class="postbox">
				<h3 class="hndle"><span>News from Optimize My Shopp</span></h3>
				<div class="inside"><p>Free eBook: <a href="http://optimizemyshopp.com/the-list/" title="Receive your free eBook delivered instantly to your inbox">10 Steps to a More Secure WordPress</a></p>
					
			</div>

			</div><div id="donate" class="postbox">
				<h3 class="hndle"><span><strong>Make a Donation!</strong></span></h3>
				<div class="inside">
					<p>Hi friend!</p><p>If this plugin is helpful for you, then please consider <a href="http://optimizemyshopp.com/go/donate-shopp-constant-contact/">making a donation</a>.</p><p>Your kindness will help me <em>pay off my student loans</em> at a faster rate.</p></div>
			</div>

							</div>
					<br><br><br>
				</div>
			</div>
<?php	
	}
}

new Shopp_ConstantContact();

?>